@@ -3,7 +3,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef SUMMARYBARWIDGET_H
 #define SUMMARYBARWIDGET_H
 
@@ -14,19 +13,18 @@ class QHBoxLayout;
 
 namespace Practice
 {
-
 class SummaryBarWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit SummaryBarWidget(QWidget *parent = 0);
+    explicit SummaryBarWidget(QWidget *parent = nullptr);
 
     void setStatistics(int correct, int wrong, int notAnswered);
 
 protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
+    bool event(QEvent *event) override;
 
 private:
     void setupCaption();
@@ -36,15 +34,15 @@ private:
 
     QPixmap captionPixmap(QColor color);
 
-    int m_correct;
-    int m_wrong;
-    int m_notAnswered;
-    int m_total;
+    int m_correct{0};
+    int m_wrong{0};
+    int m_notAnswered{0};
+    int m_total{0};
 
-    QHBoxLayout *m_layout;
-    QLabel *m_correctCaption;
-    QLabel *m_wrongCaption;
-    QLabel *m_notAnsweredCaption;
+    QHBoxLayout *m_layout{nullptr};
+    QLabel *m_correctCaption{nullptr};
+    QLabel *m_wrongCaption{nullptr};
+    QLabel *m_notAnsweredCaption{nullptr};
 
     static const int BAR_HEIGHT = 30;
 };
